@@ -3,6 +3,7 @@ Interact with reactions to various GitHub entities.
 """
 
 
+# pylint: disable=too-many-arguments
 class Reactions:
     # pylint: disable=too-many-public-methods
     """
@@ -17,8 +18,8 @@ class Reactions:
         self._execute = client._execute
 
     def list_reactions_for_a_team_discussion_comment(
-        self, org, team_slug, discussion_number, comment_number, payload=None
-    ):  # pylint: disable=too-many-arguments
+        self, org, team_slug, discussion_number, comment_number, params=None, payload=None
+    ):
         """
         List reactions for a team discussion comment
         https://docs.github.com/rest/reference/reactions#list-reactions-for-a-team-discussion-comment
@@ -37,13 +38,13 @@ class Reactions:
             self._base_url
             + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/comments/{comment_number}/reactions"  # pylint: disable=line-too-long # noqa: E501
         )
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def create_reaction_for_a_team_discussion_comment(
-        self, org, team_slug, discussion_number, comment_number, payload=None
+        self, org, team_slug, discussion_number, comment_number, params=None, payload=None
     ):
-        # pylint: disable=too-many-arguments
+
         """
         Create reaction for a team discussion comment
         https://docs.github.com/rest/reference/reactions#create-reaction-for-a-team-discussion-comment
@@ -60,13 +61,20 @@ class Reactions:
             self._base_url
             + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/comments/{comment_number}/reactions"  # pylint: disable=line-too-long # noqa: E501
         )
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def delete_team_discussion_comment_reaction(
-        self, org, team_slug, discussion_number, comment_number, reaction_id, payload=None
+        self,
+        org,
+        team_slug,
+        discussion_number,
+        comment_number,
+        reaction_id,
+        params=None,
+        payload=None,
     ):
-        # pylint: disable=too-many-arguments
+
         """
         Delete team discussion comment reaction
         https://docs.github.com/rest/reference/reactions#delete-team-discussion-comment-reaction
@@ -84,10 +92,12 @@ class Reactions:
             self._base_url
             + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/comments/{comment_number}/reactions/{reaction_id}"  # pylint: disable=line-too-long # noqa: E501
         )
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_reactions_for_a_team_discussion(self, org, team_slug, discussion_number, payload=None):
+    def list_reactions_for_a_team_discussion(
+        self, org, team_slug, discussion_number, params=None, payload=None
+    ):
         """
         List reactions for a team discussion
         https://docs.github.com/rest/reference/reactions#list-reactions-for-a-team-discussion
@@ -105,11 +115,11 @@ class Reactions:
             self._base_url
             + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/reactions"
         )
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def create_reaction_for_a_team_discussion(
-        self, org, team_slug, discussion_number, payload=None
+        self, org, team_slug, discussion_number, params=None, payload=None
     ):
         """
         Create reaction for a team discussion
@@ -126,12 +136,12 @@ class Reactions:
             self._base_url
             + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/reactions"
         )
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def delete_team_discussion_reaction(
-        self, org, team_slug, discussion_number, reaction_id, payload=None
-    ):  # pylint: disable=too-many-arguments
+        self, org, team_slug, discussion_number, reaction_id, params=None, payload=None
+    ):
         """
         Delete team discussion reaction
         https://docs.github.com/rest/reference/reactions#delete-team-discussion-reaction
@@ -148,10 +158,12 @@ class Reactions:
             self._base_url
             + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/reactions/{reaction_id}"  # pylint: disable=line-too-long # noqa: E501
         )
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_reactions_for_a_commit_comment(self, owner, repo, comment_id, payload=None):
+    def list_reactions_for_a_commit_comment(
+        self, owner, repo, comment_id, params=None, payload=None
+    ):
         """
         List reactions for a commit comment
         https://docs.github.com/rest/reference/reactions#list-reactions-for-a-commit-comment
@@ -166,10 +178,12 @@ class Reactions:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/comments/{comment_id}/reactions"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def create_reaction_for_a_commit_comment(self, owner, repo, comment_id, payload=None):
+    def create_reaction_for_a_commit_comment(
+        self, owner, repo, comment_id, params=None, payload=None
+    ):
         """
         Create reaction for a commit comment
         https://docs.github.com/rest/reference/reactions#create-reaction-for-a-commit-comment
@@ -182,12 +196,12 @@ class Reactions:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/comments/{comment_id}/reactions"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def delete_a_commit_comment_reaction(
-        self, owner, repo, comment_id, reaction_id, payload=None
-    ):  # pylint: disable=too-many-arguments
+        self, owner, repo, comment_id, reaction_id, params=None, payload=None
+    ):
         """
         Delete a commit comment reaction
         https://docs.github.com/rest/reference/reactions#delete-a-commit-comment-reaction
@@ -203,10 +217,12 @@ class Reactions:
         url = (
             self._base_url + f"/repos/{owner}/{repo}/comments/{comment_id}/reactions/{reaction_id}"
         )
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_reactions_for_an_issue_comment(self, owner, repo, comment_id, payload=None):
+    def list_reactions_for_an_issue_comment(
+        self, owner, repo, comment_id, params=None, payload=None
+    ):
         """
         List reactions for an issue comment
         https://docs.github.com/rest/reference/reactions#list-reactions-for-an-issue-comment
@@ -221,10 +237,12 @@ class Reactions:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/comments/{comment_id}/reactions"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def create_reaction_for_an_issue_comment(self, owner, repo, comment_id, payload=None):
+    def create_reaction_for_an_issue_comment(
+        self, owner, repo, comment_id, params=None, payload=None
+    ):
         """
         Create reaction for an issue comment
         https://docs.github.com/rest/reference/reactions#create-reaction-for-an-issue-comment
@@ -237,12 +255,12 @@ class Reactions:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/comments/{comment_id}/reactions"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def delete_an_issue_comment_reaction(
-        self, owner, repo, comment_id, reaction_id, payload=None
-    ):  # pylint: disable=too-many-arguments
+        self, owner, repo, comment_id, reaction_id, params=None, payload=None
+    ):
         """
         Delete an issue comment reaction
         https://docs.github.com/rest/reference/reactions#delete-an-issue-comment-reaction
@@ -259,10 +277,10 @@ class Reactions:
             self._base_url
             + f"/repos/{owner}/{repo}/issues/comments/{comment_id}/reactions/{reaction_id}"
         )
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_reactions_for_an_issue(self, owner, repo, issue_number, payload=None):
+    def list_reactions_for_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
         List reactions for an issue
         https://docs.github.com/rest/reference/reactions#list-reactions-for-an-issue
@@ -277,10 +295,10 @@ class Reactions:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/reactions"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def create_reaction_for_an_issue(self, owner, repo, issue_number, payload=None):
+    def create_reaction_for_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
         Create reaction for an issue
         https://docs.github.com/rest/reference/reactions#create-reaction-for-an-issue
@@ -293,12 +311,12 @@ class Reactions:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/reactions"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def delete_an_issue_reaction(
-        self, owner, repo, issue_number, reaction_id, payload=None
-    ):  # pylint: disable=too-many-arguments
+        self, owner, repo, issue_number, reaction_id, params=None, payload=None
+    ):
         """
         Delete an issue reaction
         https://docs.github.com/rest/reference/reactions#delete-an-issue-reaction
@@ -314,11 +332,11 @@ class Reactions:
         url = (
             self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/reactions/{reaction_id}"
         )
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
     def list_reactions_for_a_pull_request_review_comment(
-        self, owner, repo, comment_id, payload=None
+        self, owner, repo, comment_id, params=None, payload=None
     ):
         """
         List reactions for a pull request review comment
@@ -334,11 +352,11 @@ class Reactions:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/comments/{comment_id}/reactions"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def create_reaction_for_a_pull_request_review_comment(
-        self, owner, repo, comment_id, payload=None
+        self, owner, repo, comment_id, params=None, payload=None
     ):
         """
         Create reaction for a pull request review comment
@@ -352,13 +370,13 @@ class Reactions:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/comments/{comment_id}/reactions"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def delete_a_pull_request_comment_reaction(
-        self, owner, repo, comment_id, reaction_id, payload=None
+        self, owner, repo, comment_id, reaction_id, params=None, payload=None
     ):
-        # pylint: disable=too-many-arguments
+
         """
         Delete a pull request comment reaction
         https://docs.github.com/rest/reference/reactions#delete-a-pull-request-comment-reaction
@@ -375,13 +393,13 @@ class Reactions:
             self._base_url
             + f"/repos/{owner}/{repo}/pulls/comments/{comment_id}/reactions/{reaction_id}"
         )
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
     def list_reactions_for_a_pull_request_thread_comment(
-        self, owner, repo, pull_number, thread_id, comment_id, payload=None
+        self, owner, repo, pull_number, thread_id, comment_id, params=None, payload=None
     ):
-        # pylint: disable=too-many-arguments
+
         """
         List reactions for a pull request thread comment
         https://docs.github.com/rest/reference/reactions#list-reactions-for-a-pull-request-thread-comment
@@ -401,13 +419,13 @@ class Reactions:
             self._base_url
             + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments/{comment_id}/reactions"  # pylint: disable=line-too-long # noqa: E501
         )
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def create_a_reaction_to_a_pull_request_thread_comment(
-        self, owner, repo, pull_number, thread_id, comment_id, payload=None
+        self, owner, repo, pull_number, thread_id, comment_id, params=None, payload=None
     ):
-        # pylint: disable=too-many-arguments
+
         """
         Create a reaction to a pull request thread comment
         https://docs.github.com/rest/reference/reactions#create-a-reaction-to-a-pull-request-thread-comment
@@ -425,13 +443,21 @@ class Reactions:
             self._base_url
             + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments/{comment_id}/reactions"  # pylint: disable=line-too-long # noqa: E501
         )
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def delete_a_reaction_to_a_pull_request_thread_comment(
-        self, owner, repo, pull_number, thread_id, comment_id, reaction_id, payload=None
+        self,
+        owner,
+        repo,
+        pull_number,
+        thread_id,
+        comment_id,
+        reaction_id,
+        params=None,
+        payload=None,
     ):
-        # pylint: disable=too-many-arguments
+
         """
         Delete a reaction to a pull request thread comment
         https://docs.github.com/rest/reference/reactions#delete-a-thread-comment-reaction
@@ -450,10 +476,10 @@ class Reactions:
             self._base_url
             + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments/{comment_id}/reactions/{reaction_id}"  # pylint: disable=line-too-long # noqa: E501
         )
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_reactions_for_a_release(self, owner, repo, release_id, payload=None):
+    def list_reactions_for_a_release(self, owner, repo, release_id, params=None, payload=None):
         """
         List reactions for a release
         https://docs.github.com/rest/reference/reactions/#list-reactions-for-a-release
@@ -468,10 +494,10 @@ class Reactions:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/releases/{release_id}/reactions"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def create_reaction_for_a_release(self, owner, repo, release_id, payload=None):
+    def create_reaction_for_a_release(self, owner, repo, release_id, params=None, payload=None):
         """
         Create reaction for a release
         https://docs.github.com/rest/reference/reactions/#create-reaction-for-a-release
@@ -484,12 +510,12 @@ class Reactions:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/releases/{release_id}/reactions"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def delete_a_release_reaction(
-        self, owner, repo, release_id, reaction_id, payload=None
-    ):  # pylint: disable=too-many-arguments
+        self, owner, repo, release_id, reaction_id, params=None, payload=None
+    ):
         """
         Delete a release reaction
         https://docs.github.com/rest/reference/reactions/#delete-a-release-reaction
@@ -505,11 +531,11 @@ class Reactions:
         url = (
             self._base_url + f"/repos/{owner}/{repo}/releases/{release_id}/reactions/{reaction_id}"
         )
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
     def list_reactions_for_a_team_discussion_comment__legacy(
-        self, team_id, discussion_number, comment_number, payload=None
+        self, team_id, discussion_number, comment_number, params=None, payload=None
     ):
         """
         List reactions for a team discussion comment (Legacy)
@@ -528,11 +554,11 @@ class Reactions:
             self._base_url
             + f"/teams/{team_id}/discussions/{discussion_number}/comments/{comment_number}/reactions"  # pylint: disable=line-too-long # noqa: E501
         )
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def create_reaction_for_a_team_discussion_comment__legacy(
-        self, team_id, discussion_number, comment_number, payload=None
+        self, team_id, discussion_number, comment_number, params=None, payload=None
     ):
         """
         Create reaction for a team discussion comment (Legacy)
@@ -549,11 +575,11 @@ class Reactions:
             self._base_url
             + f"/teams/{team_id}/discussions/{discussion_number}/comments/{comment_number}/reactions"  # pylint: disable=line-too-long # noqa: E501
         )
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def list_reactions_for_a_team_discussion__legacy(
-        self, team_id, discussion_number, payload=None
+        self, team_id, discussion_number, params=None, payload=None
     ):
         """
         List reactions for a team discussion (Legacy)
@@ -568,11 +594,11 @@ class Reactions:
          page
         """
         url = self._base_url + f"/teams/{team_id}/discussions/{discussion_number}/reactions"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def create_reaction_for_a_team_discussion__legacy(
-        self, team_id, discussion_number, payload=None
+        self, team_id, discussion_number, params=None, payload=None
     ):
         """
         Create reaction for a team discussion (Legacy)
@@ -585,5 +611,5 @@ class Reactions:
 
         """
         url = self._base_url + f"/teams/{team_id}/discussions/{discussion_number}/reactions"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
