@@ -3,6 +3,7 @@ GHES statistics
 """
 
 
+# pylint: disable=too-many-arguments
 class ServerStatistics:
     # pylint: disable=too-few-public-methods
     """
@@ -16,7 +17,7 @@ class ServerStatistics:
         self._base_url = client._base_url
         self._execute = client._execute
 
-    def get_github_enterprise_server_statistics(self, enterprise_or_org, payload=None):
+    def get_github_enterprise_server_statistics(self, enterprise_or_org, params=None, payload=None):
         """
         Get GitHub Enterprise Server statistics
         https://docs.github.com/rest/reference/enterprise-admin#get-github-enterprise-server-statistics
@@ -28,5 +29,5 @@ class ServerStatistics:
          date_end
         """
         url = self._base_url + f"/enterprise-installation/{enterprise_or_org}/server-statistics"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
