@@ -108,7 +108,7 @@ class RestClient:
         """
         try:
             response = requests.request(
-                method=method, url=url, params=params, data=payload, headers=self._headers
+                method=method, url=url, params=params, json=payload, headers=self._headers
             )
             response.raise_for_status()
             return response
